import { Command, commands } from 'vscode';
import Controller from './controller';
import isMissionStarted from './utils/mission.util';

export class CommandHandler {
  private static _instance?: CommandHandler;
  public readonly disconnectCommand: Command;
  public readonly authenticateCommand: Command;
  public readonly openUrlInBrowserCommand: Command;

  public static get instance(): CommandHandler {
    if (!this._instance) {
      this._instance = new CommandHandler();
    }
    return this._instance;
  }

  private constructor() {
    this.disconnectCommand = { title: 'Disconnect', command: 'deadlock.disconnect' };
    this.authenticateCommand = { title: 'Authenticate', command: 'deadlock.authenticate' };
    this.openUrlInBrowserCommand = { title: 'Open url in browser', command: 'vscode.open' };
    if (!isMissionStarted()) {
      commands.registerCommand(
        this.disconnectCommand.command,
        Controller.instance.disconnect.bind(Controller.instance),
      );
    }
    commands.registerCommand(
      this.authenticateCommand.command,
      Controller.instance.authenticate.bind(Controller.instance),
    );
  }
}
