import { Response } from 'node-fetch';
import KeycloakOAuth2DeviceFlowConnection from '../core/keycloakOAuth2DeviceFlowConnection';
import { setConnected, setPending, setRefused, test_token } from '../test/service/mocks/handlers';

describe('KeycloakOAuth2DeviceFlowConnection', () => {
  let connection: KeycloakOAuth2DeviceFlowConnection;

  const log = (message: string) => console.log(`[DEADLOCK TEST] [KEYCLOAK AUTH]: ## ${message} ##`);

  it('should be pending', async () => {
    setPending();
    let response: Response | undefined = undefined;
    await connection.getToken({ openLink: log }, true).catch(async (e) => {
      response = e;
      expect(response?.status).toStrictEqual(400);

      expect(await response?.json()).toStrictEqual({
        error: 'authorization_pending',
        error_description: 'The authorization request is still pending',
      });
    });
    expect(response).toBeInstanceOf(Response);
  });

  it('should succeed', async () => {
    setConnected();
    let response: Response | undefined = undefined;
    await connection.getToken({ openLink: log }, true).catch(async (e) => {
      response = e;
      expect(response?.status).toStrictEqual(200);

      expect(await response?.json()).toStrictEqual(test_token);
    });
    expect(response).toBeInstanceOf(Response);
  });

  it('should failed with device not valid', async () => {
    setRefused();
    let response: Response | undefined = undefined;
    await connection.getToken({ openLink: log }, true).catch(async (e) => {
      response = e;
      expect(response?.status).toStrictEqual(400);

      expect(await response?.json()).toStrictEqual({
        error: 'invalid_grant',
        error_description: 'Device code not valid',
      });
    });
    expect(response).toBeInstanceOf(Response);
  });

  beforeEach(async () => {
    connection = new KeycloakOAuth2DeviceFlowConnection();
  });
});
