import { existsSync, promises } from 'fs';
import { getSshFolderPath } from './config';

export function isSshKeyPairExist(): boolean {
  return isPrivateKeyExist() && isPublicKeyExist();
}

function isPublicKeyExist(): boolean {
  return existsSync(`${getSshFolderPath()}/id_rsa.pub`);
}

function isPrivateKeyExist(): boolean {
  return existsSync(`${getSshFolderPath()}/id_rsa`);
}

export async function createSshKeyFiles(publicKey: string, privateKey: string) {
  await createSshKeyFolderIfNotExist(getSshFolderPath());
  await promises.writeFile(`${getSshFolderPath()}/id_rsa.pub`, publicKey);

  await promises.writeFile(`${getSshFolderPath()}/id_rsa`, privateKey, { mode: 0o600 });
}

async function createSshKeyFolderIfNotExist(sshKeyFolderPath) {
  if (!isSshKeyFolderExist(sshKeyFolderPath)) {
    await promises.mkdir(sshKeyFolderPath, { recursive: true });
  }
}

export function isSshKeyFolderExist(sshKeyFolderPath: string) {
  return existsSync(sshKeyFolderPath);
}
