import { exec as execCallback } from 'child_process';
import { promisify } from 'util';

const exec = promisify(execCallback);

async function getDevContainerContainers(): Promise<string[]> {
  return (await exec('docker container ps -a --format {{.Names}}')).stdout
    .split('\n')
    .filter((container) => container.includes('deadlock-mission-'));
}

async function removeContainers(...containers: string[]) {
  await exec(`docker container rm -f ${containers.join(' ')}`);
}

async function getDevContainerImages(): Promise<string[]> {
  return (await exec('docker image ls --format {{.Repository}}')).stdout
    .split('\n')
    .filter((image) => image.includes('code_'));
}

async function removeImages(...images: string[]) {
  await exec(`docker image rm -f ${images.join(' ')}`);
}

export async function clearDevContainers() {
  const containers = await getDevContainerContainers();
  const images = await getDevContainerImages();
  if (containers.length > 0) {
    await removeContainers(...containers);
  }
  if (images.length > 0) {
    await removeImages(...images);
  }
}
