import { window, ExtensionContext, workspace, commands } from 'vscode';
import Recorder from './recorder/recorder';
import { DepNodeProvider } from './view/deadlockPanel';
import { CommandTreeProvider } from './view/CommandTree';
import Controller from './core/controller';
import isMissionStarted from './core/utils/mission.util';
import AuthenticationView from './view/authenticationView';
import KeycloakOAuth2DeviceFlowConnection from './core/keycloakOAuth2DeviceFlowConnection';
import { error } from './core/utils/log';

export async function activate(context: ExtensionContext) {
  new Controller(context);
  window.showInformationMessage('Bienvenue sur Deadlock!');

  const workspaceFolders = workspace.workspaceFolders?.toString() ?? '';
  if (!workspaceFolders) window.showInformationMessage('Pas de répertoires ouverts');
  const deadlockPanelProvider = new DepNodeProvider();
  window.registerTreeDataProvider('deadlockPanel', deadlockPanelProvider);
  if (Controller.instance.startedMissions) {
    window.registerWebviewViewProvider('startedMissions', Controller.instance.startedMissions);
  }
  if (isMissionStarted()) {
    commands.executeCommand('setContext', 'deadlock.inContainer', true);
    window.registerTreeDataProvider('commandTree', new CommandTreeProvider());
    try {
      Recorder.instance.run();
    } catch (e) {
      error('Could not run recorder', e);
      window.showErrorMessage("Le recorder n'a pas pu être lancé");
    }
  } else {
    commands.executeCommand('setContext', 'deadlock.inContainer', false);
    window.registerWebviewViewProvider('authentication', AuthenticationView.instance);
  }
  KeycloakOAuth2DeviceFlowConnection.instance.checkConnection();
}
