export default class AttemptBuilder {
  public id?: string;
  public date?: number;
  public files?: Map<string, string | null>;
  public score = -1;
  public readonly treated: false;
  private _consoleContent: string;
  private _exitCode? = 408; // timeout

  constructor(
    public readonly userId: string,
    public readonly missionId: string,
    public readonly isASubmit: boolean,
    public readonly storyId?: string,
  ) {
    this.treated = false;
    this._consoleContent = '';
  }

  public addLog(log: string): void {
    this._consoleContent += `[${Date.now()}] ${log}\n`;
  }

  public setExitCode(exitCode?: number): void {
    this._exitCode = exitCode;
  }

  public get isSolved(): boolean {
    return this._exitCode === 0;
  }

  public get consoleContent(): string {
    return this._consoleContent;
  }

  build(commit?: string): Attempt {
    const files = new Map<string, string | null>();
    files['exitCode'] = this._exitCode ?? null;
    files['commit'] = commit;
    return {
      id: this.id,
      date: this.date,
      files: files,
      score: this.score,
      treated: this.treated,
      consoleContent: this.consoleContent,
      asubmit: this.isASubmit,
      storyId: this.storyId,
      solved: this.isSolved,
      userId: this.userId,
      missionId: this.missionId,
    };
  }
}

export interface Attempt {
  storyId?: string;
  score: number;
  solved: boolean;
  userId: string;
  missionId: string;
  treated: false;
  id?: string;
  date?: number;
  consoleContent: string;
  files?: Map<string, string | null>;
  asubmit: boolean;
}
