import { readFileSync } from 'fs';
import { parse } from 'yaml';
import { MISSION_FILE_IC } from '../core/config';

type level =
  | 'Jajarbinks' // le plus facile
  | 'Ewok'
  | 'Padawan'
  | 'Jedi'
  | 'Master'; // le plus difficile

interface Mission {
  readonly version: string;
  readonly name: string;
  readonly label: string;
  readonly description: string;
  readonly level: level;
  readonly type: 'DESKTOP';
  readonly xp: Map<string, number>;
  readonly desktop: {
    scripts: MissionCommand[];
  };
}

export class MissionHandler implements Mission {
  public readonly version: string;
  public readonly name: string;
  public readonly label: string;
  public readonly description: string;
  public readonly level: level;
  public readonly type: 'DESKTOP';
  public readonly desktop: { scripts: MissionCommand[] };
  public readonly xp: Map<string, number>;
  private static _instance: MissionHandler;

  public static get instance(): MissionHandler {
    if (!MissionHandler._instance) {
      MissionHandler._instance = new MissionHandler(parse(readFileSync(MISSION_FILE_IC, 'utf-8')));
    }
    return MissionHandler._instance;
  }

  private constructor(mission: Mission) {
    this.version = mission.version;
    this.name = mission.name;
    this.label = mission.label;
    this.description = mission.description;
    this.level = mission.level;
    this.type = mission.type;
    this.desktop = mission.desktop;
    this.xp = mission.xp;
  }
}

export interface MissionCommand {
  readonly name: string;
  readonly command: string;
  readonly description?: string;
  type?: 'submit' | 'setup' | 'run';
}

export default Mission;
