import { join } from 'path';
import { Command, Event, EventEmitter, TreeDataProvider, TreeItem, TreeItemCollapsibleState } from 'vscode';
import { openBriefingCommand } from '../core/controller';

const documentationLabel = 'Documentation';

export class DepNodeProvider implements TreeDataProvider<Action> {
  private _onDidChangeTreeData: EventEmitter<Action | undefined | void> = new EventEmitter<Action | undefined | void>();

  readonly onDidChangeTreeData: Event<Action | undefined | void> = this._onDidChangeTreeData.event;

  refresh(): void {
    this._onDidChangeTreeData.fire();
  }

  private root(): Action[] {
    return [new Action(documentationLabel, TreeItemCollapsibleState.Collapsed, 'folder')];
  }

  getTreeItem(element: Action): TreeItem {
    return element;
  }

  getChildren(element?: Action): Thenable<Action[]> {
    if (!element) {
      return Promise.resolve(this.root());
    } else if (element.label === documentationLabel) {
      return Promise.resolve([new Action('Briefing', TreeItemCollapsibleState.None, 'document', openBriefingCommand)]);
    }

    return Promise.resolve([]);
  }
}

export class Action extends TreeItem {
  constructor(
    public readonly label: string,
    public readonly collapsibleState: TreeItemCollapsibleState,
    public readonly iconName: string,
    public readonly command?: Command,
  ) {
    super(label, collapsibleState);
    this.tooltip = label;
    this.description = '';
  }

  iconPath = {
    light: join(__filename, '..', '..', 'resources', 'light', `${this.iconName}.svg`),
    dark: join(__filename, '..', '..', 'resources', 'dark', `${this.iconName}.svg`),
  };

  contextValue = 'dependency';
}
